@@ -1,5 +1,8 @@
-a <- c(3000, 4000, 5000, 2000)
-M <- c(100, 90, 70, 80)
+# Function ----
+
+test_that("coma is valid function", {
+  expect_function(coma, args = c("total_cost", "a", "M"))
+})
 
 # pop507 test ----
 
